@@ -1,6 +1,6 @@
 # -*-python-*-
 #
-# Copyright (C) 1999-2013 The ViewCVS Group. All Rights Reserved.
+# Copyright (C) 1999-2015 The ViewCVS Group. All Rights Reserved.
 #
 # By using this file, you agree to the terms and conditions set forth in
 # the LICENSE.html file which can be found at the top level of the ViewVC
@@ -185,7 +185,7 @@ class CheckinDatabase:
         
     def GetMetadataValue(self, name):
         sql = "SELECT value FROM metadata WHERE name=%s"
-        sql_args = (name)
+        sql_args = (name, )
         cursor = self.db.cursor()
         cursor.execute(sql, sql_args)
         try:
