@@ -1,6 +1,6 @@
 # -*-python-*-
 #
-# Copyright (C) 1999-2013 The ViewCVS Group. All Rights Reserved.
+# Copyright (C) 1999-2015 The ViewCVS Group. All Rights Reserved.
 #
 # By using this file, you agree to the terms and conditions set forth in
 # the LICENSE.html file which can be found at the top level of the ViewVC
@@ -347,6 +347,11 @@ class ModPythonServer(ThreadedServer):
     ThreadedServer.__init__(self)
     self.request = request
     self.headerSent = 0
+    # mod_python 3.3.1 and earlier add in the CGI variables by default.
+    try:
+      self.request.add_cgi_vars()
+    except AttributeError:
+      pass
     
   def addheader(self, name, value):
     self.request.headers_out.add(name, value)
