@@ -1,6 +1,6 @@
 # -*-python-*-
 #
-# Copyright (C) 2006-2013 The ViewCVS Group. All Rights Reserved.
+# Copyright (C) 2006-2015 The ViewCVS Group. All Rights Reserved.
 #
 # By using this file, you agree to the terms and conditions set forth in
 # the LICENSE.html file which can be found at the top level of the ViewVC
@@ -16,7 +16,7 @@ import string
 
 class ViewVCAuthorizer(vcauth.GenericViewVCAuthorizer):
   """A simple top-level module authorizer."""
-  def __init__(self, username, params={}):
+  def __init__(self, root_lookup_func, username, params={}):
     forbidden = params.get('forbidden', '')
     self.forbidden = map(string.strip,
                          filter(None, string.split(forbidden, ',')))
